@@ -717,14 +717,14 @@ def _list_keys(context, key_prefix, delimiter):
 
     @gen.coroutine
     def _list_first_page():
-        response = _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
-
+        response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
+        print(response)
         return _parse_list_response(response)
 
     @gen.coroutine
     def _list_later_page(token):
-
-        response = _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys, token)
+        response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys, token)
+        print(response)
 
         return _parse_list_response(response)
 
@@ -745,7 +745,7 @@ def _list_keys(context, key_prefix, delimiter):
                 directories.append(item.Prefix[:-1])
         if 'NextContinuationToken' in response:
             next_token = response.NextContinuationToken
-
+        print((next_token, keys, directories))
         return (next_token, keys, directories)
 
     token, keys, directories = yield _list_first_page()
